Changelog
=========

0.0.3
-----
#. Handle multiple likes buttons on the same page
#. Remove dependency on jmbo
#. Unit tests

0.0.2
-----
#. Prevent local cache on like redirect.

0.0.1
-----
#. Initial release.

